<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Pinpoint\CarouselManager\Api;

use Magento\Framework\Api\SearchCriteriaInterface;

interface CarouselRepositoryInterface
{

    /**
     * Save Carousel
     * @param \Pinpoint\CarouselManager\Api\Data\CarouselInterface $carousel
     * @return \Pinpoint\CarouselManager\Api\Data\CarouselInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function save(
        \Pinpoint\CarouselManager\Api\Data\CarouselInterface $carousel
    );

    /**
     * Retrieve Carousel
     * @param string $carouselId
     * @return \Pinpoint\CarouselManager\Api\Data\CarouselInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function get($carouselId);

    /**
     * Retrieve Carousel matching the specified criteria.
     * @param \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
     * @return \Pinpoint\CarouselManager\Api\Data\CarouselSearchResultsInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getList(
        \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
    );

    /**
     * Delete Carousel
     * @param \Pinpoint\CarouselManager\Api\Data\CarouselInterface $carousel
     * @return bool true on success
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function delete(
        \Pinpoint\CarouselManager\Api\Data\CarouselInterface $carousel
    );

    /**
     * Delete Carousel by ID
     * @param string $carouselId
     * @return bool true on success
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function deleteById($carouselId);
}

