<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Pinpoint\CarouselManager\Controller\Adminhtml\Carousel;

use Pinpoint\CarouselManager\Model\CarouselRepository;

class Delete extends \Pinpoint\CarouselManager\Controller\Adminhtml\Carousel
{
    /**
     * @var CarouselRepository
     */
    private $carouselRepository;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        CarouselRepository $carouselRepository,
        \Magento\Framework\Registry $coreRegistry)
    {
        parent::__construct($context, $coreRegistry);
        $this->carouselRepository = $carouselRepository;
    }


    /**
     * Delete action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('carousel_id');
        if ($id) {
            try {
                $this->carouselRepository->deleteById($id);
                // display success message
                $this->messageManager->addSuccessMessage(__('You deleted the Carousel.'));
                // go to grid
                return $resultRedirect->setPath('*/*/');
            } catch (\Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('*/*/edit', ['carousel_id' => $id]);
            }
        }
        // display error message
        $this->messageManager->addErrorMessage(__('We can\'t find a Carousel to delete.'));
        // go to grid
        return $resultRedirect->setPath('*/*/');
    }
}

