<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * @category    Pinpoint
 * @copyright   Copyright (c) 2020 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Daniel Cuevas <daniel@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CarouselManager\Model\Source;

/**
 * Class VisualSelect
 */
class VisualSelect implements \Magento\Framework\Data\OptionSourceInterface
{
    /**
     * @var \Magento\Framework\View\Asset\Repository
     */
    private $assetRepo;

    /**
     * @var array
     */
    private $optionsData;

    /**
     * @var string|null
     */
    private $optionsSize;

    private $optionsParsed = null;

    /**
     * Visual Select constructor.
     *
     * @param \Magento\Framework\View\Asset\Repository $assetRepo
     * @param array $optionsData
     * @param string|null $optionsSize
     */
    public function __construct(
        \Magento\Framework\View\Asset\Repository $assetRepo,
        array $optionsData,
        $optionsSize
    ) {
        $this->assetRepo = $assetRepo;
        $this->optionsData = $optionsData;
        $this->optionsSize  = $optionsSize;
    }

    /**
     * Returns options for Visual Select based on di configuration
     *
     * @return array
     */
    public function toOptionArray(): array
    {
        if (is_null($this->optionsParsed)) {
            if ($this->optionsData) {
                $this->optionsParsed = [];
                foreach ($this->optionsData as $optionKey => $optionValue) {
                    if (isset($optionValue['icon'])) {
                        $optionValue['icon'] = $this->assetRepo->getUrl($optionValue['icon']);
                    }
                    $optionValue['size'] = $this->optionsSize ?? 'small';
                    $this->optionsParsed[$optionKey] = $optionValue;
                }
            } else {
                return [];
            }
        }

        return $this->optionsParsed;
    }
}
